# Plot of allele frequencies over time.

x <- read.csv("loberg lake Eda frequencies over time", stringsAsFactors = FALSE)

# p is EDAFcount/EDATotcount

# Simulate forward using Felicity's EDA estimates of s, h, p1983

s <- 0.490612252
h <- 0.228842567
p <- 0.009625531 # 1983
q <- 1 - p
yr <- 1983
z <- vector()
i <- 1
while(yr < 2010){
	if(yr == 1983) z[i] <- p  #cat("\n", yr, p, "\n")
	yr <- yr + 1
	i <- i + 1
	pnext <- ( p^2 + p*q*(1-h*s) ) / ( p^2 + 2*p*q*(1-h*s) + q^2*(1-s) )
	p <- pnext
	q <- 1 - p
	z[i] <- p  # cat(yr, p, "\n")	
	}

y <- data.frame(yr = 1983:2010, p = z)
y
	     # yr           p
	# 1  1983 0.009625531
	# 2  1984 0.016559187
	# 3  1985 0.028228363
	# 4  1986 0.047402187
	# 5  1987 0.077723023
	# 6  1988 0.122972222
	# 7  1989 0.185262122
	# 8  1990 0.262812623
	# 9  1991 0.349426464
	# 10 1992 0.436937258
	# 11 1993 0.518637589
	# 12 1994 0.590907963
	# 13 1995 0.652801792
	# 14 1996 0.704921181
	# 15 1997 0.748502859
	# 16 1998 0.784902470
	# 17 1999 0.815366175
	# 18 2000 0.840956738
	# 19 2001 0.862549229
	# 20 2002 0.880852812
	# 21 2003 0.896438910
	# 22 2004 0.909767914
	# 23 2005 0.921211891
	# 24 2006 0.931072964
	# 25 2007 0.939597859
	# 26 2008 0.946989281
	# 27 2009 0.953414786
	# 28 2010 0.959013707

all(x$year == y[,1]) # check that the years are the same

x$predicted <- y[,2]
x$observed <- x$EDAFcount/x$EDATotcount

# Plot Fig 6A
par(fin = c(6,4.5))
plot(predicted ~ year, data = x, type = "l", bty = "l", las = 1, cex = 1.5, lwd = 1.5, 
	cex.axis = 0.9, cex.lab = 1.3, xlab = "Year", ylab = "Eda allele frequency", 
	xaxp = c(1983,2010,9), ylim=c(0,1))
points(observed ~ year, data = x, pch = 16, col = "firebrick")
x$se <- sqrt( x$observed * (1 - x$observed)/x$EDATotcount )
segments(x$year, x$observed - x$se, x$year, x$observed + x$se, col = "firebrick")
text(x = 1983, y = 1, "A", cex = 1.5)


# ---------
# Fst at loci each year compared with 1992

x <- read.csv("loberg lake fst values.csv", stringsAsFactors = FALSE)

# Test differences between markers in slope
# Use a test of a significant slope of the difference in Fst
anova(lm( (Eda-stn60) ~ year - 1, data = x))
	# Response: (Eda - stn60)
	          # Df  Sum Sq Mean Sq F value  Pr(>F)  
	# year       1 0.41338 0.41338  10.968 0.01291 *
	# Residuals  7 0.26382 0.03769                  

anova(lm( (Eda-stn239) ~ year - 1, data = x))
	# Response: (Eda - stn239)
	          # Df  Sum Sq Mean Sq F value Pr(>F)  
	# year       1 0.41567 0.41567  10.971 0.0129 *
	# Residuals  7 0.26521 0.03789                 

anova(lm( (Eda-stn277) ~ year - 1, data = x))
	# Response: (Eda - stn277)
	          # Df  Sum Sq Mean Sq F value  Pr(>F)  
	# year       1 0.35200 0.35200  11.631 0.01128 *
	# Residuals  7 0.21185 0.03026
	
# Plot of Figure 6B
par(fin = c(6,4.5))
plot(Eda ~ year, data = x, las = 1, bty = "l", xlab = "Year", ylab = "Fst", cex.lab = 1.3, 
		pch = 16, type = "p", cex = 1.5, xaxp = c(1992,2008,8), lwd = 1.5, col = "firebrick")
lines(Eda ~ year, data = x, lwd = 1.5, col = "firebrick")
lines(stn60 ~ year, data = x, lwd = 1.5)
points(stn60 ~ year, data = x, pch = 1, cex = 1.5)
points(stn239 ~ year, data = x, pch = 2, cex = 1.5)
lines(stn239 ~ year, data = x, lwd = 1.5)
points(stn277 ~ year, data = x, pch = 5, cex = 1.5)
lines(stn277 ~ year, data = x, lwd = 1.5)
text(x = 1992, y = 0.45, "B", cex = 1.5)
